package com.ebei.screen.controller.video;

import cn.hutool.core.bean.BeanUtil;
import com.ebei.screen.common.response.ResponseBean;
import com.ebei.screen.modules.po.CameraDevice;
import com.ebei.screen.modules.po.MachineRoom;
import com.ebei.screen.modules.po.Project;
import com.ebei.screen.service.CameraDeviceService;
import com.ebei.screen.service.MachineRoomService;
import com.ebei.screen.service.ProjectService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.constraints.NotNull;
import java.util.List;

/**
 * @author Liu.x
 * @description 视频监控大屏
 */

@Slf4j
@Validated
@RestController
@RequestMapping("/video")
@AllArgsConstructor
@Api(value = "视频监控", tags = "视频监控api")
public class VideoMonitorController {

    @Autowired
    private ProjectService projectService;
    @Autowired
    private CameraDeviceService cameraDeviceService;
    @Autowired
    private MachineRoomService machineRoomService;

    @ApiOperation("保存项目")
    @PostMapping("/saveProject")
    public ResponseBean saveProject(@RequestBody Project project) {
        projectService.saveProject(project);
        return ResponseBean.success();
    }

    @ApiOperation("修改项目")
    @PostMapping("/updateProject")
    public ResponseBean updateProject(@RequestBody Project project) {
        if(BeanUtil.isEmpty(project.getId())) {
            return ResponseBean.fail("id不能为空");
        }
        return projectService.updateProject(project);
    }

    @ApiOperation("分页查询项目")
    @PostMapping("/queryProject/{page}/{pageSize}")
    public ResponseBean queryProjectPage(@PathVariable("page") @NotNull(message = "URL参数：当前页的页码不能为空") Integer page,
                                      @PathVariable("pageSize") @NotNull(message = "URL参数：当前页的页数不能为空") Integer pageSize,
                                      @RequestParam(value = "name",required = false) String name) {

        return projectService.queryProjectPage(page-1,pageSize,name);
    }

    @ApiOperation("同步萤石设备")
    @GetMapping("/syncAllYsDevice")
    public ResponseBean syncAllYsDevice() {

        try {
            cameraDeviceService.syncAllYsDevice();
        } catch (Exception e) {
            log.error(e.getMessage());
        }
        return ResponseBean.success("后台同步中，请不要重复点击!");

    }

    @ApiOperation("分页查询萤石设备")
    @PostMapping("/queryYsDevice/{page}/{pageSize}")
    public ResponseBean queryYsDevice(@PathVariable("page") @NotNull(message = "URL参数：当前页的页码不能为空") Integer page,
                                         @PathVariable("pageSize") @NotNull(message = "URL参数：当前页的页数不能为空") Integer pageSize,
                                         @RequestParam(value = "name",required = false) String name,
                                      @RequestParam(value = "deviceSerial",required = false) String deviceSerial,
                                      @RequestParam(value = "status",required = false) String status) {

        return cameraDeviceService.queryProjectPage(page-1,pageSize,name,deviceSerial,status);
    }

    @ApiOperation("保存机房")
    @PostMapping("/saveMachineRoom")
    public ResponseBean saveMachineRoom(@RequestBody MachineRoom machineRoom) {
        machineRoomService.saveMachineRoom(machineRoom);
        return ResponseBean.success();
    }

    @ApiOperation("修改机房(可用于关联监控设备)")
    @PostMapping("/updateMachineRoom")
    public ResponseBean updateMachineRoom(@RequestBody MachineRoom machineRoom) {
        if(BeanUtil.isEmpty(machineRoom.getId())) {
            return ResponseBean.fail("id不能为空");
        }
        machineRoomService.updateMachineRoom(machineRoom);
        return ResponseBean.success();
    }

    @ApiOperation("根据项目分页查询机房(视频大屏首页使用)")
    @PostMapping("/queryMachineRoom/{page}/{pageSize}")
    public ResponseBean queryMachineRoom(@PathVariable("page") @NotNull(message = "URL参数：当前页的页码不能为空") Integer page,
                                      @PathVariable("pageSize") @NotNull(message = "URL参数：当前页的页数不能为空") Integer pageSize,
                                      @RequestParam(value = "projectId",required = false) Long projectId,
                                      @RequestParam(value = "name",required = false) String name) {
        return machineRoomService.queryMachineRoom(page-1,pageSize,name,projectId);
    }

}
